import LexicalUnitDisplay from './LexicalUnitDisplay.js';
import LexicalUnitEdit from './LexicalUnitEdit.js';

export default {
  components: {LexicalUnitDisplay, LexicalUnitEdit},
  props: {
    entryId: Number,
    lexicalUnitId: Number,
  },
  data () {
    return this.getInitialData();
  },
  methods: {
    getInitialData () {
      return { isEdit: false, key: this.lexicalUnitId, unifiedFrameId: Number, };
    },
    goToEdit (unifiedFrameId) {
      this.isEdit = true;
      this.unifiedFrameId = unifiedFrameId;
    },
    refresh () {
      this.key = null;
      setTimeout(() => { this.key = this.lexicalUnitId; }, 0);
      update_entries();
    }
  },
  watch: {
    lexicalUnitId () {
      Object.assign(this, this.getInitialData());
    }
  },
  template: `
    <div class="col h-100 px-1 pt-0 pb-2 overflow-auto" id="semantics-frames-pane">
      <div v-if="key" :key="key">
        <lexical-unit-display
          v-if="lexicalUnitId && !isEdit"
          :entryId="entryId"
          :lexicalUnitId="lexicalUnitId"
          @go-to-edit="goToEdit"
          @refresh="refresh"
        />
        <lexical-unit-edit v-if="isEdit" :unifiedFrameId="unifiedFrameId" />
      </div>
    </div>
    <div class="col h-100 px-1 pt-0 pb-0 overflow-auto" id="semantics-schemata-pane">
      <div id="semantics-schemata"></div>
    </div>
  `
}
